import { Bounds } from '@itk-viewer/utils/bounding-box.js';
import { ReadonlyVec3, mat4, vec3, quat, ReadonlyQuat } from 'gl-matrix';
import { ActorRefFrom, AnyActorRef } from 'xstate';
export type Pose = {
    center: vec3;
    rotation: quat;
    distance: number;
};
export type ReadonlyPose = {
    readonly center: ReadonlyVec3;
    readonly rotation: ReadonlyQuat;
    readonly distance: number;
};
export declare const toMat4: (out: mat4, pose: ReadonlyPose) => mat4;
type Context = {
    pose: Pose;
    enableRotation: boolean;
    verticalFieldOfView: number;
    parallelScaleRatio: number;
    poseWatchers: Array<AnyActorRef>;
};
type SetPoseEvent = {
    type: 'setPose';
    pose: ReadonlyPose & {
        parallelScale?: number;
    };
};
export declare const cameraMachine: import("xstate").StateMachine<Context, SetPoseEvent | {
    type: "watchPose";
    watcher: AnyActorRef;
} | {
    type: "watchPoseStop";
    watcher: AnyActorRef;
} | {
    type: "setEnableRotation";
    enable: boolean;
}, {}, never, {
    type: "emitNewPose";
    params: {
        pose: Pose;
        parallelScaleRatio: number;
    };
}, never, never, "active", string, import("xstate").NonReducibleUnknown, import("xstate").NonReducibleUnknown, import("xstate").EventObject, import("xstate").MetaObject, {
    readonly id: "camera";
    readonly initial: "active";
    readonly context: () => {
        pose: {
            center: vec3;
            rotation: quat;
            distance: number;
        };
        enableRotation: true;
        parallelScaleRatio: number;
        verticalFieldOfView: number;
        poseWatchers: never[];
    };
    readonly states: {
        readonly active: {
            readonly on: {
                readonly setPose: {
                    readonly actions: readonly [import("xstate").ActionFunction<Context, SetPoseEvent, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>, {
                        readonly type: "emitNewPose";
                        readonly params: ({ context: { pose, parallelScaleRatio } }: {
                            context: Context;
                            event: SetPoseEvent;
                        }) => {
                            pose: Pose;
                            parallelScaleRatio: number;
                        };
                    }];
                };
                readonly watchPose: {
                    readonly actions: readonly [import("xstate").ActionFunction<Context, {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>, ({ context: { pose, parallelScaleRatio }, event: { watcher } }: import("xstate").ActionArgs<Context, {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }>) => void];
                };
                readonly watchPoseStop: {
                    readonly actions: readonly [import("xstate").ActionFunction<Context, {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>];
                };
                readonly setEnableRotation: {
                    readonly actions: import("xstate").ActionFunction<Context, {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>;
                };
            };
        };
    };
}>;
export declare const createCamera: () => import("xstate").Actor<import("xstate").StateMachine<Context, SetPoseEvent | {
    type: "watchPose";
    watcher: AnyActorRef;
} | {
    type: "watchPoseStop";
    watcher: AnyActorRef;
} | {
    type: "setEnableRotation";
    enable: boolean;
}, {}, never, {
    type: "emitNewPose";
    params: {
        pose: Pose;
        parallelScaleRatio: number;
    };
}, never, never, "active", string, import("xstate").NonReducibleUnknown, import("xstate").NonReducibleUnknown, import("xstate").EventObject, import("xstate").MetaObject, {
    readonly id: "camera";
    readonly initial: "active";
    readonly context: () => {
        pose: {
            center: vec3;
            rotation: quat;
            distance: number;
        };
        enableRotation: true;
        parallelScaleRatio: number;
        verticalFieldOfView: number;
        poseWatchers: never[];
    };
    readonly states: {
        readonly active: {
            readonly on: {
                readonly setPose: {
                    readonly actions: readonly [import("xstate").ActionFunction<Context, SetPoseEvent, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>, {
                        readonly type: "emitNewPose";
                        readonly params: ({ context: { pose, parallelScaleRatio } }: {
                            context: Context;
                            event: SetPoseEvent;
                        }) => {
                            pose: Pose;
                            parallelScaleRatio: number;
                        };
                    }];
                };
                readonly watchPose: {
                    readonly actions: readonly [import("xstate").ActionFunction<Context, {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>, ({ context: { pose, parallelScaleRatio }, event: { watcher } }: import("xstate").ActionArgs<Context, {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }>) => void];
                };
                readonly watchPoseStop: {
                    readonly actions: readonly [import("xstate").ActionFunction<Context, {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>];
                };
                readonly setEnableRotation: {
                    readonly actions: import("xstate").ActionFunction<Context, {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, SetPoseEvent | {
                        type: "watchPose";
                        watcher: AnyActorRef;
                    } | {
                        type: "watchPoseStop";
                        watcher: AnyActorRef;
                    } | {
                        type: "setEnableRotation";
                        enable: boolean;
                    }, undefined, never, never, never, never, never>;
                };
            };
        };
    };
}>>;
export type Camera = ActorRefFrom<typeof cameraMachine>;
export declare const reset3d: (pose: Pose, verticalFieldOfView: number, bounds: Bounds, aspect: number) => {
    center: vec3;
    rotation: quat;
    distance: number;
};
export declare const reset2d: (pose: Pose, verticalFieldOfView: number, pointsToFit: Array<ReadonlyVec3>, aspect: number) => {
    center: vec3;
    rotation: quat;
    distance: number;
    parallelScale: number;
};
export {};
//# sourceMappingURL=camera.d.ts.map