import { assign, createActor, raise, setup } from 'xstate';
export const viewerMachine = setup({
    types: {},
}).createMachine({
    id: 'viewer',
    initial: 'active',
    context: {
        viewports: [],
        images: {},
    },
    states: {
        active: {
            on: {
                createChild: {
                    actions: [
                        assign({
                            viewports: ({ spawn, context: { viewports }, event: { logic, onActor }, }) => {
                                const child = spawn(logic);
                                onActor(child);
                                return [...viewports, child];
                            },
                        }),
                    ],
                },
                setImage: {
                    actions: [
                        assign({
                            images: ({ event: { image, name = 'image' }, context }) => ({
                                ...context.images,
                                [name]: image,
                            }),
                        }),
                        raise(({ context }) => ({
                            type: 'sendImageToViewports',
                            image: Object.values(context.images).at(-1),
                        })),
                    ],
                },
                sendImageToViewports: {
                    actions: [
                        ({ context, event: { image } }) => {
                            Object.values(context.viewports).forEach((viewport) => {
                                viewport.send({
                                    type: 'setImage',
                                    image,
                                });
                            });
                        },
                    ],
                },
            },
        },
    },
});
export const createViewer = () => {
    return createActor(viewerMachine).start();
};
//# sourceMappingURL=viewer.js.map