import { assign, sendParent, setup } from 'xstate';
import { cameraMachine } from './camera.js';
export const viewportMachine = setup({
    types: {},
    actions: {
        forwardToParent: sendParent(({ event }) => {
            return event;
        }),
        forwardToViews: ({ context, event }) => {
            context.views.forEach((actor) => {
                actor.send(event);
            });
        },
    },
    actors: {
        camera: cameraMachine,
    },
}).createMachine({
    id: 'viewport',
    context: ({ spawn }) => ({
        resolution: [0, 0],
        views: [],
        camera: spawn('camera', { id: 'camera' }),
    }),
    initial: 'active',
    states: {
        active: {
            on: {
                createChild: {
                    actions: [
                        assign({
                            views: ({ spawn, context: { views }, event: { logic, onActor }, self, }) => {
                                const child = spawn(logic);
                                child.send({ type: 'setViewport', viewport: self });
                                const { camera } = self.getSnapshot().children;
                                child.send({ type: 'setCamera', camera });
                                onActor(child);
                                return [...views, child];
                            },
                        }),
                    ],
                },
                setImage: {
                    actions: [
                        assign({
                            image: ({ event: { image } }) => image,
                        }),
                        'forwardToViews',
                    ],
                },
                setCamera: {
                    actions: [
                        assign({
                            camera: ({ event: { camera } }) => camera,
                        }),
                        'forwardToViews',
                    ],
                },
                setResolution: {
                    actions: [
                        assign({
                            resolution: ({ event: { resolution } }) => resolution,
                        }),
                        'forwardToParent',
                    ],
                },
            },
        },
    },
});
//# sourceMappingURL=viewport.js.map